@@ -23,8 +23,11 @@
  * tcpslice - extract pieces of and/or glue together pcap files
  */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
+
+// For fileno() and getopt().
+#if defined(__SUNPRO_C) && ! defined(__EXTENSIONS__)
+#define __EXTENSIONS__
 #endif
 
 #include <sys/types.h>
@@ -33,9 +36,7 @@
 #include <sys/time.h>
 
 #include <ctype.h>
-#ifdef HAVE_FCNTL_H
 #include <fcntl.h>
-#endif
 #include <memory.h>
 #include <pcap.h>
 #include <stdio.h>
@@ -44,13 +45,7 @@
 #include <time.h>
 #include <unistd.h>
 #include <errno.h>
-
-#if HAVE_STDINT_H
 #include <stdint.h>
-#endif
-#ifndef INT32_MAX
-#define INT32_MAX (2147483647)
-#endif
 
 #ifdef HAVE_OS_PROTO_H
 #include "os-proto.h"
@@ -202,7 +197,7 @@ main(int argc, char **argv)
 		case 'h':
 			print_usage(stdout);
 			exit(0);
-			break;
+			/* NOTREACHED */
 
 		case 'l':
 			relative_time_merge = 1;
@@ -1130,6 +1125,11 @@ print_usage(FILE *f)
 
 #endif /* HAVE_LIBNIDS */
 
+#if defined(SIZEOF_VOID_P) && defined(SIZEOF_TIME_T)
+	(void)fprintf (f, "%u-bit build, %u-bit time_t\n",
+		       SIZEOF_VOID_P * 8, SIZEOF_TIME_T * 8);
+#endif
+
 	(void)fprintf(f,
 	              "Usage: tcpslice [-DdhlRrtv] [-w file]\n"
 	              "                [ -s types [ -e seconds ] [ -f format ] ]\n"
